proxy — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# proxy

Proxy objects for the model that live in the GUI thread and are able to respond immediately. They do so by keeping a local copy of the data of the real model

We take copies of the data in the elixir model, because accessing an attribute on the model, might cause an sql query which might take a long time, and might freeze the gui

class `camelot.view.proxy.` `ValueLoading`

  Class indicating that a value was not yet loaded into the proxy

- collection_proxy
- queryproxy

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus